Re:Reference count, don't garbage collect
by mbrodersen on Saturday July 30, 2022 @09:01PM
(#32292045)
You are 100% right. At some point I measured smart_ptr to be 25x slower than raw pointers. The compiler I am maintaining is not using C++ style smart pointers. It is using a global whole program optimisation pass to reduce reference manipulation to a minimum. Basically what a world class C++ programmer with years of experience optimising performance would do. It is just done automatically.
[ Parent
| on HN ]
There are no comments on this comment yet.